import { AbstractPowerSyncDatabaseOpenFactory } from '@journeyapps/powersync-sdk-common';
import { PowerSyncDatabase } from '../../db/PowerSyncDatabase';
import { SSRDBAdapter } from './SSRDBAdapter';
/**
 * Intermediate PowerSync Database Open factory for Web which uses a mock
 * SSR DB Adapter if running on server side.
 * Most SQLite DB implementations only run on client side, this will safely return
 * empty query results in SSR which will allow for generating server partial views.
 */
export class AbstractWebPowerSyncDatabaseOpenFactory extends AbstractPowerSyncDatabaseOpenFactory {
    isServerSide() {
        return typeof window == 'undefined';
    }
    constructor(options) {
        super(options);
        this.options = options;
    }
    generateOptions() {
        const isServerSide = this.isServerSide();
        if (isServerSide && !this.options.disableSSRWarning) {
            console.warn(`
  Running PowerSync in SSR mode.
  Only empty query results will be returned.
  Disable this warning by setting 'disableSSRWarning: true' in options.`);
        }
        return {
            database: isServerSide ? new SSRDBAdapter() : this.openDB(),
            schema: this.schema
        };
    }
    generateInstance(options) {
        return new PowerSyncDatabase(options);
    }
}
//# sourceMappingURL=AbstractWebPowerSyncDatabaseOpenFactory.js.map